==> monaco-vscode-view-common-service-override-7.0.9.tgz: package/vscode/src/vs/workbench/browser/parts/sidebar/sidebarActions.js <==
import './media/sidebarpart.css.js';
import { localize2WithPath } from 'vscode/vscode/vs/nls';
import { Action2, registerAction2 } from 'vscode/vscode/vs/platform/actions/common/actions';
import { Parts } from 'vscode/vscode/vs/workbench/services/layout/browser/layoutService';
import { IWorkbenchLayoutService } from 'vscode/vscode/vs/workbench/services/layout/browser/layoutService.service';
import { KeyMod, KeyCode } from 'vscode/vscode/vs/base/common/keyCodes';
import { KeybindingWeight } from 'vscode/vscode/vs/platform/keybinding/common/keybindingsRegistry';
import { Categories } from 'vscode/vscode/vs/platform/action/common/actionCommonCategories';
import { IPaneCompositePartService } from 'vscode/vscode/vs/workbench/services/panecomposite/browser/panecomposite.service';
import { ViewContainerLocation } from 'vscode/vscode/vs/workbench/common/views';

const _moduleId = "vs/workbench/browser/parts/sidebar/sidebarActions";
class FocusSideBarAction extends Action2 {
    constructor() {
        super({
            id: 'workbench.action.focusSideBar',
            title: ( localize2WithPath(_moduleId, 0, 'Focus into Primary Side Bar')),
            category: Categories.View,
            f1: true,
            keybinding: {
                weight: KeybindingWeight.WorkbenchContrib,
                when: null,
                primary: KeyMod.CtrlCmd | KeyCode.Digit0
            }
        });
    }
    async run(accessor) {
        const layoutService = accessor.get(IWorkbenchLayoutService);
        const paneCompositeService = accessor.get(IPaneCompositePartService);
        if (!layoutService.isVisible(Parts.SIDEBAR_PART)) {
            layoutService.setPartHidden(false, Parts.SIDEBAR_PART);
        }
        const viewlet = paneCompositeService.getActivePaneComposite(ViewContainerLocation.Sidebar);
        viewlet?.focus();
    }
}
registerAction2(FocusSideBarAction);

export { FocusSideBarAction };

==> monaco-vscode-view-common-service-override-8.0.0.tgz: package/vscode/src/vs/workbench/browser/parts/sidebar/sidebarActions.js <==
import './media/sidebarpart.css.js';
import { localize2 } from 'vscode/vscode/vs/nls';
import { Action2, registerAction2 } from 'vscode/vscode/vs/platform/actions/common/actions';
import { Parts } from 'vscode/vscode/vs/workbench/services/layout/browser/layoutService';
import { IWorkbenchLayoutService } from 'vscode/vscode/vs/workbench/services/layout/browser/layoutService.service';
import { KeyMod, KeyCode } from 'vscode/vscode/vs/base/common/keyCodes';
import { KeybindingWeight } from 'vscode/vscode/vs/platform/keybinding/common/keybindingsRegistry';
import { Categories } from 'vscode/vscode/vs/platform/action/common/actionCommonCategories';
import { IPaneCompositePartService } from 'vscode/vscode/vs/workbench/services/panecomposite/browser/panecomposite.service';
import { ViewContainerLocation } from 'vscode/vscode/vs/workbench/common/views';

class FocusSideBarAction extends Action2 {
    constructor() {
        super({
            id: 'workbench.action.focusSideBar',
            title: ( localize2(9270, 'Focus into Primary Side Bar')),
            category: Categories.View,
            f1: true,
            keybinding: {
                weight: KeybindingWeight.WorkbenchContrib,
                when: null,
                primary: KeyMod.CtrlCmd | KeyCode.Digit0
            }
        });
    }
    async run(accessor) {
        const layoutService = accessor.get(IWorkbenchLayoutService);
        const paneCompositeService = accessor.get(IPaneCompositePartService);
        if (!layoutService.isVisible(Parts.SIDEBAR_PART)) {
            layoutService.setPartHidden(false, Parts.SIDEBAR_PART);
        }
        const viewlet = paneCompositeService.getActivePaneComposite(ViewContainerLocation.Sidebar);
        viewlet?.focus();
    }
}
registerAction2(FocusSideBarAction);

export { FocusSideBarAction };
